@@ -267,7 +267,6 @@ def funcMaemoVersion():
 
 def funcProcInfo():
         print "** Start Function - Processor Information **"
-        # This one reads fremantle version number (Firmware)
         ga = os.popen('cat /proc/cpuinfo | grep Processor').read()	
         return ga.strip()[11:]
 
@@ -347,3 +346,28 @@ def funcCPUMinMax():
         b = int(b) / 1000
         c = str(b) + "MHz" + " / " + str(a) + "MHz"
         return c.strip()
+
+def FMTxPropertiesInterfaceConnect():
+
+	bus = dbus.SystemBus()
+
+	dbus_object = bus.get_object('com.nokia.FMTx', '/com/nokia/fmtx/default', False)
+
+	dbus_interface = dbus.Interface(dbus_object, dbus_interface='org.freedesktop.DBus.Properties')
+
+	return dbus_interface
+
+def GetProp(dbus_interface, prop):
+	return dbus_interface.Get('org.freedesktop.DBus.Properties', prop)
+
+def FMTxState():
+	return GetProp(FMTxPropertiesInterfaceConnect(), 'state')
+
+def FMTxFrequency():
+	a = GetProp(FMTxPropertiesInterfaceConnect(), 'frequency')
+	a = a /100
+	return a
+
+def FMTxStartable():
+	return GetProp(FMTxPropertiesInterfaceConnect(), 'startable')
+
