@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.2.1-1
+# Application Name - Health Check V1.2.1-2
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -626,6 +626,15 @@ class Ui_MainWindow(QtGui.QMainWindow):
                 elif sela[0].strip() == "Device Orientation":
                         orientation = gn_functions.funcDevOri()
                         self.listWidget.currentItem().setText("Device Orientation \t\t" + orientation)
+                elif sela[0].strip() == "FM Trans State":
+                        g = gn_functions.FMTxState()
+                        self.listWidget.currentItem().setText("FM Trans State \t\t" + g)
+                elif sela[0].strip() == "FM Trans Frequency":      
+                        g = gn_functions.FMTxFrequency()
+                        self.listWidget.currentItem().setText("FM Trans Frequency \t\t" + str(g))
+                elif sela[0].strip() == "FM Trans Startable?":       
+                        g = gn_functions.FMTxStartable()
+                        self.listWidget.currentItem().setText("FM Trans Startable? \t\t" + g)
                 else:
                         print "else", sela[0].strip()
 
@@ -848,7 +857,13 @@ class Ui_MainWindow(QtGui.QMainWindow):
                 g = gn_functions.funcCPUMinMax()
                 self.listWidget.addItem("CPU Min / Max Frequencies \t" + g)
                 
-		
+                g = gn_functions.FMTxState()
+                self.listWidget.addItem("FM Trans State \t\t" + g)
+                g = gn_functions.FMTxFrequency()
+                self.listWidget.addItem("FM Trans Frequency \t\t" + str(g))
+                g = gn_functions.FMTxStartable()
+                self.listWidget.addItem("FM Trans Startable? \t\t" + g)
+                
 
 	def funcUpdateAll(self):
 		print " ** Running Update ALL**"
